\name{Athaliana}
\docType{package}

\alias{BSgenome.Athaliana.TAIR.TAIR9-package}
\alias{BSgenome.Athaliana.TAIR.TAIR9}
\alias{Athaliana}


\title{Arabidopsis thaliana full genome (TAIR9)}

\description{
  Arabidopsis thaliana full genome as provided by TAIR (TAIR9 Genome Release) and stored in Biostrings objects. Note that TAIR10 is an "annotation release" based on the same genome assembly as TAIR9.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
ftp://ftp.arabidopsis.org/home/tair/Genes/TAIR9_genome_release/TAIR9_chr_all.fas

  }
  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the BSgenome software
  package for how to make a BSgenome data package.
}

\author{H. Pages}

\seealso{
  \link[BSgenome]{BSgenome-class},
  \link[Biostrings]{DNAString-class},
  \code{\link[BSgenome]{available.genomes}},
  \link[BSgenome]{BSgenomeForge}
}

\examples{
Athaliana
seqlengths(Athaliana)
Athaliana$Chr1  # same as Athaliana[["Chr1"]]

if ("AGAPS" \%in\% masknames(Athaliana)) {

  ## Check that the assembly gaps contain only Ns:
  checkOnlyNsInGaps <- function(seq)
  {
    ## Replace all masks by the inverted AGAPS mask
    masks(seq) <- gaps(masks(seq)["AGAPS"])
    unique_letters <- uniqueLetters(seq)
    if (any(unique_letters != "N"))
        stop("assembly gaps contain more than just Ns")
  }

  ## A message will be printed each time a sequence is removed
  ## from the cache:
  options(verbose=TRUE)

  for (seqname in seqnames(Athaliana)) {
    cat("Checking sequence", seqname, "... ")
    seq <- Athaliana[[seqname]]
    checkOnlyNsInGaps(seq)
    cat("OK\n")
  }
}

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}
